self.__BUILD_MANIFEST=function(s,c,a,e,t,f,u,n,b,o,j,r,i,k,h){return{__rewrites:{afterFiles:[],beforeFiles:[],fallback:[]},"/":["static/chunks/pages/index-444f1804401f04ea.js"],"/_error":["static/chunks/pages/_error-c66a4e8afc46f17b.js"],"/clusters":["static/chunks/pages/clusters-ee39056f9851a3ff.js"],"/clusters/[cluster]":[s,c,a,f,u,j,o,e,t,n,r,b,i,k,h,"static/chunks/6856-6373e4e2ed938603.js","static/chunks/1871-7e202677c42f43fe.js","static/chunks/pages/clusters/[cluster]-abfcac9c137aa543.js"],"/clusters/[cluster]/[job]":[s,c,a,f,e,t,b,"static/chunks/pages/clusters/[cluster]/[job]-792db96d918c98c9.js"],"/config":["static/chunks/pages/config-dfb9bf07b13045f4.js"],"/infra":["static/chunks/pages/infra-aed0ea19df7cf961.js"],"/infra/[context]":["static/chunks/pages/infra/[context]-c0b5935149902e6f.js"],"/jobs":["static/chunks/pages/jobs-2072b48b617989c9.js"],"/jobs/pools/[pool]":[s,c,a,u,o,e,t,n,"static/chunks/pages/jobs/pools/[pool]-9faf940b253e3e06.js"],"/jobs/[job]":[s,c,a,f,u,o,e,t,n,b,"static/chunks/pages/jobs/[job]-d66997e2bfc837cf.js"],"/users":["static/chunks/pages/users-f42674164aa73423.js"],"/volumes":["static/chunks/pages/volumes-b84b948ff357c43e.js"],"/workspace/new":["static/chunks/pages/workspace/new-3f88a1c7e86a3f86.js"],"/workspaces":["static/chunks/pages/workspaces-531b2f8c4bf89f82.js"],"/workspaces/[name]":[s,c,a,f,u,j,e,t,n,r,b,i,k,h,"static/chunks/1141-e6aa9ab418717c59.js","static/chunks/pages/workspaces/[name]-84a40f8c7c627fe4.js"],sortedPages:["/","/_app","/_error","/clusters","/clusters/[cluster]","/clusters/[cluster]/[job]","/config","/infra","/infra/[context]","/jobs","/jobs/pools/[pool]","/jobs/[job]","/users","/volumes","/workspace/new","/workspaces","/workspaces/[name]"]}}("static/chunks/616-3d59f75e2ccf9321.js","static/chunks/6130-2be46d70a38f1e82.js","static/chunks/5739-d67458fcb1386c92.js","static/chunks/6989-01359c57e018caa4.js","static/chunks/3850-ff4a9a69d978632b.js","static/chunks/7411-b15471acd2cba716.js","static/chunks/1272-1ef0bf0237faccdb.js","static/chunks/8969-452f9d5cbdd2dc73.js","static/chunks/9353-cff34f7e773b2e2b.js","static/chunks/6212-7bd06f60ba693125.js","static/chunks/7359-c8d04e06886000b3.js","static/chunks/6990-9146207c4567fdfd.js","static/chunks/2260-7703229c33c5ebd5.js","static/chunks/3800-7b45f9fbb6308557.js","static/chunks/7615-019513abc55b3b47.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();